@@ -378,10 +378,11 @@ def _validate_tiddler_headers(environ, tiddler):
                     tiddler.modified)
             last_modified = ('Last-Modified', last_modified_string)
             incoming_modified = environ.get('HTTP_IF_MODIFIED_SINCE', None)
-            if incoming_modified and \
-                    (web.datetime_from_http_date(incoming_modified) >=
-                            web.datetime_from_http_date(last_modified_string)):
-                raise HTTP304('')
+            if incoming_modified:
+                incoming_modified = web.datetime_from_http_date(incoming_modified)
+                if incoming_modified and (incoming_modified >=
+                        web.datetime_from_http_date(last_modified_string)):
+                    raise HTTP304('')
 
     else:
         incoming_etag = environ.get('HTTP_IF_MATCH', None)
