@@ -4,17 +4,22 @@ This consolidates common code for bags and recipes.
 """
 
 from tiddlyweb.serializer import Serializer, NoSerializationError
-from tiddlyweb.web.http import HTTP415
-from tiddlyweb.web.util import get_serialize_type, encode_name
-from tiddlyweb.util import sha
+from tiddlyweb.web.http import HTTP304, HTTP415
+from tiddlyweb.web.util import get_serialize_type, entity_etag
 
 
 def send_entity(environ, start_response, entity):
     """
     Send a bag or recipe out HTTP, first serializing to
-    the correct type.
+    the correct type. If the incoming etag matches, raise
+    304.
     """
-    username = environ['tiddlyweb.usersign']['name']
+    etag_string = entity_etag(environ, entity)
+    incoming_etag = environ.get('HTTP_IF_NONE_MATCH', None)
+    if incoming_etag:
+        if incoming_etag == etag_string:
+            raise HTTP304(incoming_etag)
+
     try:
         serialize_type, mime_type = get_serialize_type(environ)
         serializer = Serializer(serialize_type, environ)
@@ -23,11 +28,9 @@ def send_entity(environ, start_response, entity):
     except NoSerializationError:
         raise HTTP415('Content type %s not supported' % mime_type)
 
-    etag_string = '"%s"' % (sha(_entity_etag(entity) +
-        encode_name(username) + encode_name(mime_type)).hexdigest())
-
     start_response("200 OK",
             [('Content-Type', mime_type),
+                ('Cache-Control', 'no-cache'),
                 ('ETag', etag_string),
                 ('Vary', 'Accept')])
 
@@ -35,20 +38,3 @@ def send_entity(environ, start_response, entity):
         return [content]
     else:
         return content
-
-
-def _entity_etag(entity):
-    """
-    Generate a unique hash from the contents of the entity.
-    """
-    etag = ''
-    etag += entity.name
-    for attr in entity.policy.attributes:
-        etag += '%s' % getattr(entity.policy, attr)
-    try:
-        for item in entity:
-            etag += '%s' % item
-    except TypeError:
-        # entity not a iterator
-        pass
-    return etag.encode('utf-8')
