@@ -115,9 +115,10 @@ def _validate_tiddler_list(environ, tiddlers):
             raise HTTP304(incoming_etag)
     else:
         incoming_modified = environ.get('HTTP_IF_MODIFIED_SINCE', None)
-        if incoming_modified and \
-                (datetime_from_http_date(incoming_modified) >= \
-                datetime_from_http_date(last_modified_string)):
-            raise HTTP304('')
+        if incoming_modified:
+            incoming_modified = datetime_from_http_date(incoming_modified)
+            if incoming_modified and (incoming_modified >=
+                    datetime_from_http_date(last_modified_string)):
+                raise HTTP304('')
 
     return last_modified, etag
